@@ -57,13 +57,42 @@
 #'
 #'
 #' @export
-#' @param components A [component_list] object
-#' @param lhoods A list of one or more `lhood` objects
+#' @param components A [bru_comp_list] object
+#' @param lhoods Either a [bru_obs()] object, a [bru_obs_list()] object, or
+#'   a list of one or more [bru_obs()] or [bru_obs_list()] objects,
+#'   or a list of arguments for a call to [bru_obs()].
+#' @param options A [bru_options] options object or a list of options passed
+#' on to [bru_options()]
+#' @param .envir The environment in which the components are evaluated.
+#'
 #' @return A [bru_model] object
 #' @keywords internal
 
-bru_model <- function(components, lhoods) {
-  stopifnot(inherits(components, "component_list"))
+bru_model <- function(components,
+                      lhoods,
+                      options = list(),
+                      .envir = parent.frame()) {
+  options <- bru_call_options(options)
+
+  .response <- extract_response(components)
+
+  # Turn input into a list of components (from existing list, or a special
+  # formula)
+  components <- bru_comp_list(components, .envir = .envir)
+
+  lhoods <- bru_obs_list_construct(
+    lhoods,
+    options = options,
+    .envir = .envir,
+    .response = .response,
+    .components = components
+  )
+
+  if (length(lhoods) == 0) {
+    stop("No observation models provided.")
+  }
+
+  inputs <- bru_input(lhoods, components = components, null.on.fail = FALSE)
 
   # Back up environment
   env <- environment(components)
@@ -73,16 +102,15 @@ bru_model <- function(components, lhoods) {
   included <- bru_used(lhoods)
   included <- union(included[["effect"]], included[["latent"]])
 
-  # Detect linearity
-  linear <- all(vapply(lhoods, function(lh) lh[["linear"]], TRUE))
-  # TODO: detect pure effect additivity (allowing nonlinear components)
-
   # Complete the used component definitions based on data
-  components <- bru_component_list(components[included], lhoods)
+  components <- bru_comp_list(
+    components[included],
+    lhoods = lhoods,
+    inputs = inputs
+  )
 
   for (cmp in included) {
-    if (linear ||
-      !(components[[cmp]][["main"]][["type"]] %in% c("offset", "const"))) {
+    if (!(components[[cmp]][["main"]][["type"]] %in% c("offset", "const"))) {
       formula <- update.formula(formula, components[[cmp]]$inla.formula)
     }
   }
@@ -91,12 +119,30 @@ bru_model <- function(components, lhoods) {
   environment(components) <- env
   environment(formula) <- env
 
+  # Check linearity
+  for (lh in seq_along(lhoods)) {
+    if (lhoods[[lh]][["linear"]]) {
+      used_lh <- bru_used(lhoods[[lh]])
+      used_lh <- unique(c(used_lh$effect, used_lh$latent))
+      lhoods[[lh]][["linear"]] <-
+        all(vapply(components[used_lh], function(cmp) {
+          ibm_is_linear(cmp$mapper)
+        }, TRUE))
+    }
+  }
+
   # Make model
   mdl <- structure(
-    list(effects = components, formula = formula),
+    list(
+      effects = components,
+      lhoods = lhoods,
+      inputs = inputs,
+      formula = formula
+    ),
     class = "bru_model"
   )
-  return(mdl)
+
+  mdl
 }
 
 
@@ -117,13 +163,20 @@ summary.bru_model <- function(object, ...) {
 }
 
 #' @export
-#' @param x A `summary_bru_model` object to be printed
+#' @param x An object to be printed
 #' @rdname bru_model
 print.summary_bru_model <- function(x, ...) {
   print(x[["components"]])
   invisible(x)
 }
 
+#' @export
+#' @rdname bru_model
+print.bru_model <- function(x, ...) {
+  print(summary(x))
+  invisible(x)
+}
+
 
 
 
@@ -134,8 +187,10 @@ print.summary_bru_model <- function(x, ...) {
 #' @param state list of state lists, as generated by [evaluate_state()]
 #' @param data A `list`, `data.frame`, or `Spatial*DataFrame`, with coordinates
 #' and covariates needed to evaluate the predictor.
+#' @param data_extra Additional data for the predictor evaluation
 #' @param input Precomputed inputs list for the components
-#' @param comp_simple Precomputed `comp_simple_list` for the components
+#' @param comp_simple Precomputed [bm_list] of simplified mappers for the
+#' components
 #' @param predictor A formula or an expression to be evaluated given the
 #' posterior or for each sample thereof. The default (`NULL`) returns a
 #' `data.frame` containing the sampled effects. In case of a formula the right
@@ -165,6 +220,7 @@ print.summary_bru_model <- function(x, ...) {
 evaluate_model <- function(model,
                            state,
                            data = NULL,
+                           data_extra = NULL,
                            input = NULL,
                            comp_simple = NULL,
                            predictor = NULL,
@@ -178,14 +234,14 @@ evaluate_model <- function(model,
     stop("Not enough information to evaluate model states.")
   }
   if (is.null(input)) {
-    input <- input_eval(
+    input <- bru_input(
       components = model$effects[used$effect],
-      data = data,
-      inla_f = TRUE
+      data = data
     )
   }
   if (is.null(comp_simple) && !is.null(input)) {
-    comp_simple <- evaluate_comp_simple(model$effects[used$effect],
+    comp_simple <- ibm_simplify(
+      model$effects[used$effect],
       input = input,
       inla_f = TRUE
     )
@@ -193,11 +249,17 @@ evaluate_model <- function(model,
   if (is.null(comp_simple)) {
     effects <- NULL
   } else {
-    effects <- evaluate_effect_multi_state(
-      comp_simple,
-      state = state,
-      input = input
-    )
+    effects <-
+      lapply(
+        state,
+        function(x) {
+          evaluate_effect_single_state(
+            comp_simple,
+            state = x,
+            input = input
+          )
+        }
+      )
   }
 
   if (is.null(predictor)) {
@@ -208,6 +270,7 @@ evaluate_model <- function(model,
     model,
     state = state,
     data = data,
+    data_extra = data_extra,
     effects = effects,
     predictor = predictor,
     format = format,
@@ -273,11 +336,6 @@ evaluate_state <- function(model,
 evaluate_effect_single_state <- function(...) {
   UseMethod("evaluate_effect_single_state")
 }
-#' @export
-#' @rdname evaluate_effect
-evaluate_effect_multi_state <- function(...) {
-  UseMethod("evaluate_effect_multi_state")
-}
 
 #' Evaluate a component effect
 #'
@@ -286,15 +344,13 @@ evaluate_effect_multi_state <- function(...) {
 #'
 #' @export
 #' @keywords internal
-#' @param component A `bru_mapper`, `bru_component`, `comp_simple`, or
-#'   `comp_simple_list`.
+#' @param component A [bru_mapper], [bru_comp], or
+#'   [bm_list].
 #' @param input Pre-evaluated component input
-#' @param state Specification of one (for `evaluate_effect_single_state`) or
-#'   several (for `evaluate_effect_multi_State`) latent variable states:
+#' @param state Specification of one latent variable state:
 #' * `evaluate_effect_single_state.bru_mapper`:
 #'   A vector of the latent component state.
 #' * `evaluate_effect_single_state.*_list`: list of named state vectors.
-#' * `evaluate_effect_multi_state.*_list`: list of lists of named state vectors.
 #' @param ... Optional additional parameters, e.g. `inla_f`. Normally unused.
 #' @param label Option label used for any warning messages, specifying the
 #' affected component.
@@ -328,15 +384,15 @@ evaluate_effect_single_state.bru_mapper <- function(component, input, state,
   as.vector(as.matrix(values))
 }
 
-#' @return * `evaluate_effect_single_state.component_list`: A list of evaluated
-#' component effect values
+#' @return * `evaluate_effect_single_state.bm_list`: A list of
+#'   evaluated component effect values
 #' @export
 #' @rdname evaluate_effect
 #' @keywords internal
-evaluate_effect_single_state.comp_simple_list <- function(components,
-                                                          input,
-                                                          state,
-                                                          ...) {
+evaluate_effect_single_state.bm_list <- function(components,
+                                                 input,
+                                                 state,
+                                                 ...) {
   result <- list()
   for (label in names(components)) {
     result[[label]] <- evaluate_effect_single_state(
@@ -350,47 +406,15 @@ evaluate_effect_single_state.comp_simple_list <- function(components,
   result
 }
 
-#' @return * `evaluate_effect_multi.comp_simple_list`: A list of lists of
-#' evaluated component effects, one list for each state
 #' @export
 #' @rdname evaluate_effect
 #' @keywords internal
-evaluate_effect_multi_state.comp_simple_list <- function(components,
-                                                         input,
-                                                         state,
-                                                         ...) {
-  lapply(
-    state,
-    function(x) {
-      evaluate_effect_single_state(
-        components,
-        input = input,
-        state = x,
-        ...
-      )
-    }
-  )
-}
-
-#' @export
-#' @rdname evaluate_effect
-#' @keywords internal
-evaluate_effect_single_state.component_list <- function(components,
-                                                        input,
-                                                        state,
-                                                        ...) {
-  comp_simple <- evaluate_comp_simple(components, input = input, ...)
-  evaluate_effect_single_state(comp_simple, input = input, state = state, ...)
-}
-#' @export
-#' @rdname evaluate_effect
-#' @keywords internal
-evaluate_effect_multi_state.component_list <- function(components,
+evaluate_effect_single_state.bru_comp_list <- function(components,
                                                        input,
                                                        state,
                                                        ...) {
-  comp_simple <- evaluate_comp_simple(components, input = input, ...)
-  evaluate_effect_multi_state(comp_simple, input = input, state = state, ...)
+  comp_simple <- ibm_simplify(components, input = input, state = state, ...)
+  evaluate_effect_single_state(comp_simple, input = input, state = state, ...)
 }
 
 
@@ -403,10 +427,13 @@ evaluate_effect_multi_state.component_list <- function(components,
 #'
 #' @param data A `list`, `data.frame`, or `Spatial*DataFrame`, with coordinates
 #' and covariates needed to evaluate the model.
+#' @param data_extra Additional data for the predictor evaluation. Variables
+#' with the same name as in `data` will be ignored, unless accessed via
+#' `.data_extra.[["name"]]` or `.data_extra.$name`.
 #' @param state A list where each element is a list of named latent state
 #' information, as produced by [evaluate_state()]
 #' @param effects A list where each element is list of named evaluated effects,
-#' as computed by [evaluate_effect_multi_state.component_list()]
+#' each computed by [evaluate_effect_single_state.bru_comp_list()]
 #' @param predictor Either a formula or expression
 #' @param used A [bru_used()] object, or NULL (default)
 #' @param format character; determines the storage format of the output.
@@ -423,13 +450,14 @@ evaluate_effect_multi_state.component_list <- function(components,
 #' vectors of length `n_pred`.
 #' @details For each component, e.g. "name", the state values are available as
 #'   `name_latent`, and arbitrary evaluation can be done with `name_eval(...)`,
-#'   see [bru_component_eval()].
+#'   see [bru_comp_eval()].
 #' @return A list or matrix is returned, as specified by `format`
 #' @keywords internal
 #' @rdname evaluate_predictor
 evaluate_predictor <- function(model,
                                state,
                                data,
+                               data_extra,
                                effects,
                                predictor,
                                used = NULL,
@@ -455,6 +483,7 @@ evaluate_predictor <- function(model,
 
   used <- bru_used(used, labels = names(model$effects))
 
+  # General evaluation environment
   envir <- new.env(parent = enclos)
   # Find .data. first,
   # then data variables,
@@ -466,11 +495,29 @@ evaluate_predictor <- function(model,
   #
   # Note: Since 2.7.0.9019, no longer converts Spatial*DataFrame to data frame
   # here; coordinates must be accessed via sp::coordinates() if needed.
-  for (nm in names(data)) {
-    assign(nm, data[[nm]], envir = envir)
+  if (!is.null(data)) {
+    if (inherits(data, "Spatial")) {
+      for (nm in names(data)) {
+        assign(nm, data[[nm]], envir = envir)
+      }
+    } else {
+      list2env(data, envir = envir)
+    }
   }
   assign(".data.", data, envir = envir)
 
+  nms <- setdiff(names(data_extra), names(data))
+  if (!is.null(data_extra[nms])) {
+    if (inherits(data_extra, "Spatial")) {
+      for (nm in nms) {
+        assign(nm, data_extra[[nm]], envir = envir)
+      }
+    } else {
+      list2env(data_extra[nms], envir = envir)
+    }
+  }
+  assign(".data_extra.", data_extra, envir = envir)
+
   # Rename component states from label to label_latent
   state_names <- as.list(expand_labels(
     names(state[[1]]),
@@ -500,11 +547,15 @@ evaluate_predictor <- function(model,
                            replicate = NULL,
                            weights = NULL,
                            .state = NULL) {
+        n_input <- ibm_n_output(
+          .mapper[["mappers"]][["mapper"]][["mappers"]][["main"]],
+          input = main
+        )
         if (is.null(group)) {
-          group <- rep(1, NROW(main))
+          group <- rep(1, n_input)
         }
         if (is.null(replicate)) {
-          replicate <- rep(1, NROW(main))
+          replicate <- rep(1, n_input)
         }
         if (!.is_offset && is.null(.state)) {
           .state <- eval(
@@ -584,8 +635,13 @@ evaluate_predictor <- function(model,
       eval_fun
     }
   for (nm in names(eval_names)) {
-    assign(eval_names[[nm]],
-      eval_fun_factory(model$effects[[nm]], .envir = envir, .enclos = enclos),
+    assign(
+      eval_names[[nm]],
+      eval_fun_factory(
+        model$effects[[nm]],
+        .envir = envir,
+        .enclos = enclos
+      ),
       envir = envir
     )
   }
@@ -643,6 +699,7 @@ evaluate_predictor <- function(model,
 #' In predictor expressions, `name_eval(...)` can be used to evaluate
 #' the effect of a component called "name".
 #'
+#' @aliases bru_component_eval
 #' @param main,group,replicate,weights Specification of where to evaluate a
 #'   component. The four inputs are passed on to the joint `bru_mapper` for the
 #'   component, as
@@ -653,42 +710,56 @@ evaluate_predictor <- function(model,
 #'         replicate = replicate),
 #'       scale = weights)
 #'  ```
+#'  NOTE: If you have model component with the same name as a data variable you
+#'  want to supply as input to `name_eval()`, you need to use
+#'  `.data.[["myvar"]]` to access it. Otherwise, it will try to use the other
+#'  component effect as input, which is ill-defined.
 #' @param .state The internal component state. Normally supplied automatically
 #' by the internal methods for evaluating inlabru predictor expressions.
 #' @return A vector of values for a component
 #' @examples
-#' \dontrun{
-#' if (bru_safe_inla()) {
+#' if (bru_safe_inla() &&
+#'   require("sf", quietly = TRUE) &&
+#'   requireNamespace("sn", quietly = TRUE)) {
 #'   mesh <- fmesher::fm_mesh_2d_inla(
 #'     cbind(0, 0),
-#'     offset = 2, max.edge = 0.25
+#'     offset = 2,
+#'     max.edge = 2.5
 #'   )
-#'   spde <- INLA::inla.spde2.pcmatern(mesh,
-#'     prior.range = c(0.1, 0.01),
-#'     prior.sigma = c(2, 0.01)
+#'   spde <- INLA::inla.spde2.pcmatern(
+#'     mesh,
+#'     prior.range = c(1, NA),
+#'     prior.sigma = c(0.2, NA)
 #'   )
-#'   data <- sp::SpatialPointsDataFrame(
-#'     matrix(runif(10), 5, 2),
-#'     data = data.frame(z = rnorm(5))
+#'   set.seed(12345L)
+#'   data <- sf::st_as_sf(
+#'     data.frame(
+#'       x = runif(50),
+#'       y = runif(50),
+#'       z = rnorm(50)
+#'     ),
+#'     coords = c("x", "y")
 #'   )
-#'   fit <- bru(z ~ -1 + field(coordinates, model = spde),
-#'     family = "gaussian", data = data
+#'   fit <- bru(
+#'     z ~ -1 + field(geometry, model = spde),
+#'     family = "gaussian", data = data,
+#'     options = list(control.inla = list(int.strategy = "eb"))
 #'   )
-#'   pred <- predict(
+#'   pred <- generate(
 #'     fit,
-#'     data = data.frame(x = 0.5, y = 0.5),
-#'     formula = ~ field_eval(cbind(x, y))
+#'     newdata = data.frame(A = 0.5, B = 0.5),
+#'     formula = ~ field_eval(cbind(A, B)),
+#'     n.samples = 1L
 #'   )
 #' }
-#' }
-bru_component_eval <- function(main,
-                               group = NULL,
-                               replicate = NULL,
-                               weights = NULL,
-                               .state = NULL) {
+bru_comp_eval <- function(main,
+                          group = NULL,
+                          replicate = NULL,
+                          weights = NULL,
+                          .state = NULL) {
   stop(paste0(
     "In your predictor expression, use 'mylabel_eval(...)' instead of\n",
-    "'bru_component_eval(...)'.  See ?bru_component_eval for more information."
+    "'bru_comp_eval(...)'.  See ?bru_comp_eval for more information."
   ))
 }
 
@@ -696,185 +767,203 @@ bru_component_eval <- function(main,
 
 
 
-#' @title Compute all component linearisations
-#'
+
+
+#' @include mappers.R
+
+#' @title Mapper methods for model objects
 #' @description
-#' Computes individual `bru_mapper_taylor` objects for included components
-#' for each model likelihood
+#' Methods for the `ibm_linear()` and `ibm_simplify()` methods for
+#' [bru] model objects and related classes.
 #'
-#' @param model A `bru_model` object
-#' @param input A list of named lists of component inputs
-#' @param state A named list of component states
-#' @param inla_f Controls the input data interpretations
-#' @param options A `bru_options` object. The log verbosity options
-#' are used.
-#' @return A list (class 'comp_simple') of named lists (class
-#'   'comp_simple_list') of `bru_mapper_taylor` objects, one for each included
-#'   component
-#' @rdname evaluate_comp_lin
-#' @keywords internal
-evaluate_comp_lin <- function(model, input, state, inla_f = FALSE,
-                              options = NULL) {
+#' @inheritParams bru_mapper_generics
+#'
+#' @name bru_model_mapper_methods
+#' @rdname bru_model_mapper_methods
+NULL
+
+#' @describeIn bru_model_mapper_methods Returns a list (one element per
+#'   observation model) of [bm_list] objects, each with one [bm_taylor]
+#'   entry for each included component.
+#' @export
+ibm_linear.bru_model <- function(mapper, input, state = NULL, ...) {
+  model <- mapper
   stopifnot(inherits(model, "bru_model"))
+  bru_log_message(
+    paste0("Linearise components for each observation model"),
+    verbosity = 3
+  )
   mappers <-
     lapply(
       input,
       function(inp) {
-        included <- parse_inclusion(
-          names(model[["effects"]]),
-          names(inp),
-          NULL
+        ibm_linear(
+          model[["effects"]],
+          input = inp,
+          state = state,
+          ...
         )
-
-        mappers <- comp_lin_eval(
-          model[["effects"]][included],
-          input = inp[included],
-          state = state[included],
-          inla_f = inla_f,
-          options = options
-        )
-
-        class(mappers) <- c("comp_simple_list", class(mappers))
-        mappers
       }
     )
 
-  class(mappers) <- c("comp_simple_list_list", class(mappers))
   mappers
 }
 
-#' @title Compute simplified component mappings
-#'
-#' @description
-#' Computes individual `bru_mapper_taylor` objects for included linear
-#' components for each model likelihood, and keeps non-linear mappers intact.
-#'
-#' @param model A `bru_model` object
-#' @param input A list of named lists of component inputs
-#' @param inla_f Controls the input data interpretations
-#' @return A list (class 'comp_simple_list_list') of named lists (class
-#'   'comp_simple_list') of `bru_mapper` objects, one for each included
-#'   component
+#' @rdname bru_model_mapper_methods
 #' @export
-#' @keywords internal
-#' @rdname evaluate_comp_simple
-evaluate_comp_simple <- function(...) {
-  UseMethod("evaluate_comp_simple")
+ibm_linear.bru_comp_list <- function(mapper, input, state = NULL, ...) {
+  comp <- mapper
+  included <- parse_inclusion(
+    names(comp),
+    names(input),
+    NULL
+  )
+
+  mappers <- ibm_linear(
+    as_bm_list(comp[included]),
+    input = input[included],
+    state = state[included],
+    ...
+  )
+
+  mappers
 }
 
+#' @rdname bru_model_mapper_methods
 #' @export
-#' @param options A `bru_options` object. The log verbosity options
-#' are used.
-#' @rdname evaluate_comp_simple
-evaluate_comp_simple.component_list <- function(components, input,
-                                                inla_f = FALSE, ...,
-                                                options = NULL) {
+ibm_linear.bru_comp <- function(mapper,
+                                input,
+                                state = NULL,
+                                ...) {
+  bru_log_message(
+    paste0("Linearise component '", mapper[["label"]], "'"),
+    verbosity = 5
+  )
+  if (is.null(state)) {
+    state <- rep(0, ibm_n(mapper[["mapper"]]))
+  }
+  ibm_linear(mapper[["mapper"]], input = input, state = state, ...)
+}
+
+#' @describeIn bru_model_mapper_methods Returns a list (one element per
+#'   observation model) of [bm_list] objects, each with one [bru_mapper]
+#'   entry for each included component.
+#' @export
+ibm_simplify.bru_model <- function(mapper, input = NULL, state = NULL, ...) {
+  model <- mapper
+  bru_log_message(
+    paste0("Simplify component mappers for each observation model"),
+    verbosity = 3
+  )
+  mappers <-
+    lapply(
+      input,
+      function(inp) {
+        ibm_simplify(
+          model[["effects"]],
+          input = inp,
+          state = state,
+          ...
+        )
+      }
+    )
+
+  mappers
+}
+
+#' @rdname bru_model_mapper_methods
+#' @export
+ibm_simplify.bru_comp <- function(mapper,
+                                  input = NULL,
+                                  state = NULL,
+                                  ...) {
+  bru_log_message(
+    paste0("Linearise component '", mapper[["label"]], "'"),
+    verbosity = 5
+  )
+  if (is.null(state)) {
+    state <- rep(0, ibm_n(mapper[["mapper"]]))
+  }
+  ibm_simplify(mapper[["mapper"]], input = input, state = state, ...)
+}
+
+
+#' @rdname bru_model_mapper_methods
+#' @export
+ibm_simplify.bru_comp_list <- function(mapper,
+                                       input = NULL,
+                                       state = NULL,
+                                       ...) {
+  comp <- mapper
+  included <- parse_inclusion(names(comp), names(input), NULL)
+
+  mappers <- ibm_simplify(
+    as_bm_list(comp[included]),
+    input = input[included],
+    state = state[included],
+    ...
+  )
+
+  mappers
+}
+
+
+# @title Mapper methods for model objects
+# @description
+# Methods for the `ibm_linear()` and `ibm_simplify()` methods for
+# [bru] model objects and related classes.
+#
+#' @inheritParams bru_mapper_generics
+#'
+#' @export
+#' @rdname bm_list
+#' @export
+ibm_linear.bm_list <- function(mapper, input, state = NULL, ...) {
+  label <- names(mapper)
+  if (is.null(label)) {
+    label <- as.character(seq_along(mapper))
+  }
   mappers <- lapply(
-    components,
-    function(x) {
-      label <- x[["label"]]
+    seq_along(mapper),
+    function(k) {
       bru_log_message(
-        paste0("Simplify component '", label, "'"),
-        verbose = options$bru_verbose,
-        verbose_store = options$bru_verbose_store,
+        paste0("Linearise component '", label[k], "'"),
+        verbosity = 4
+      )
+      ibm_linear(
+        mapper[[k]],
+        input[[k]],
+        state = NULL,
+        ...
+      )
+    }
+  )
+  names(mappers) <- names(mapper)
+  as_bm_list(mappers)
+}
+
+#' @rdname bm_list
+#' @export
+ibm_simplify.bm_list <- function(mapper, input = NULL, state = NULL, ...) {
+  label <- names(mapper)
+  if (is.null(label)) {
+    label <- as.character(seq_along(mapper))
+  }
+  mappers <- lapply(
+    seq_along(mapper),
+    function(k) {
+      bru_log_message(
+        paste0("Simplify component '", label[k], "'"),
         verbosity = 4
       )
       ibm_simplify(
-        x[["mapper"]],
-        input[[label]],
+        mapper[[k]],
+        input[[k]],
         state = NULL,
-        inla_f = inla_f
+        ...
       )
     }
   )
-
-  class(mappers) <- c("comp_simple_list", class(mappers))
-  mappers
-}
-
-#' @export
-#' @rdname evaluate_comp_simple
-evaluate_comp_simple.bru_model <- function(model, input, ...) {
-  mappers <-
-    lapply(
-      input,
-      function(inp) {
-        included <- parse_inclusion(
-          names(model[["effects"]]),
-          names(inp),
-          NULL
-        )
-
-        evaluate_comp_simple(model[["effects"]][included], input = inp, ...)
-      }
-    )
-
-  class(mappers) <- c("comp_simple_list_list", class(mappers))
-  mappers
-}
-
-#' @describeIn evaluate_comp_simple
-#' Subsetting of comp_simple_list objects, retaining class
-#' @export
-#' @param x `comp_simple_list` object from which to extract element(s)
-#' @param i indices specifying elements to extract
-#' @keywords internal
-`[.comp_simple_list` <- function(x, i) {
-  env <- environment(x)
-  object <- NextMethod()
-  class(object) <- c("comp_simple_list", "list")
-  environment(object) <- env
-  object
-}
-
-
-
-#' Compute all component inputs
-#'
-#' Computes the component inputs for included components
-#' for each model likelihood
-#'
-#' @param model A `bru_model` object
-#' @param lhoods A `bru_like_list` object
-#' @param inla_f logical
-#' @rdname evaluate_inputs
-#' @keywords internal
-evaluate_inputs <- function(model, lhoods, inla_f) {
-  stopifnot(inherits(model, "bru_model"))
-  lapply(
-    lhoods,
-    function(lh) {
-      included <- bru_used(lh)[["effect"]]
-
-      input_eval(
-        model$effects[included],
-        data = lh[["data"]],
-        inla_f = inla_f
-      )
-    }
-  )
-}
-
-#' Compute all index values
-#'
-#' Computes the index values matrices for included components
-#'
-#' @param model A `bru_model` object
-#' @param lhoods A `bru_like_list` object. Deprecated and ignored
-#' @return A named list of `idx_full` and `idx_inla`,
-#' named list of indices, and `inla_subset`, and `inla_subset`,
-#' a named list of logical subset specifications for extracting the `INLA::f()`
-#' compatible index subsets.
-#' @rdname evaluate_index
-#' @keywords internal
-evaluate_index <- function(model, lhoods) {
-  stopifnot(inherits(model, "bru_model"))
-  included <- bru_used(lhoods)
-  included <- union(included[["effect"]], included[["latent"]])
-
-  list(
-    idx_full = index_eval(model[["effects"]][included], inla_f = FALSE),
-    idx_inla = index_eval(model[["effects"]][included], inla_f = TRUE),
-    inla_subset = inla_subset_eval(model[["effects"]][included])
-  )
+  names(mappers) <- names(mapper)
+  as_bm_list(mappers)
 }
