@@ -18,7 +18,8 @@ check_spatstat <- function(pkg = "spatstat.geom") {
     spst_ver <- try(utils::packageVersion("spatstat"), silent = TRUE)
     if (!inherits(spst_ver, "try-error") && spst_ver < "2.0-0") {
       warning(paste0(
-        "You have an old version of 'spatstat' installed which is incompatible with '",
+        "You have an old version of 'spatstat' installed which is ",
+        "incompatible with '",
         pkg,
         "'. Please update 'spatstat' (or uninstall it)."
       ))
@@ -30,24 +31,28 @@ check_spatstat <- function(pkg = "spatstat.geom") {
 
 #' Convert SpatialPoints and boundary polygon to spatstat ppp object
 #'
-#' Spatstat point pattern objects consist of points and an observation windows. This
-#' function uses a SpatialPoints object and a SpatialPolygon object to generate the points
-#' and the window. Lastly, the ppp() function is called to create the `ppp` object.
+#' Spatstat point pattern objects consist of points and an observation windows.
+#' This function uses a `SpatialPoints` object and a `SpatialPolygon` object to
+#' generate the points and the window. Lastly, the `ppp()` function is called to
+#' create the `ppp` object.
 #'
-#' @aliases spatial.to.ppp
 #' @export
-#' @param points A `SpatialPoints[DataFrame]` object describing the point pattern.
-#' @param samplers A `SpatialPolygons[DataFrame]` object describing the observation window.
+#' @param points A `SpatialPoints[DataFrame]` object describing the point
+#'   pattern.
+#' @param samplers A `SpatialPolygons[DataFrame]` object describing the
+#'   observation window.
 #' @return A spatstat `spatstat` `ppp` object
 #'
 #' @examples
 #' \donttest{
 #' if (require("spatstat.geom") &&
 #'   bru_safe_sp() &&
-#'   require("sp")) {
+#'   require("sp") &&
+#'   require("terra", quietly = TRUE) &&
+#'   require("sf", quietly = TRUE)) {
 #'   # Load Gorilla data
 #'
-#'   data("gorillas", package = "inlabru")
+#'   gorillas <- gorillas_sp()
 #'
 #'   # Use nest locations and survey boundary to create a spatstat ppp object
 #'
@@ -60,14 +65,17 @@ check_spatstat <- function(pkg = "spatstat.geom") {
 #' }
 #' }
 #'
+#' @keywords internal
 spatial.to.ppp <- function(points, samplers) {
   check_spatstat("spatstat.geom")
 
   bnd <- samplers@polygons[[1]]@Polygons[[1]]@coords
   bnd <- bnd[1:(nrow(bnd) - 1), ]
   gp <- spatstat.geom::ppp(
-    x = coordinates(points)[, 1],
-    y = coordinates(points)[, 2],
-    window = spatstat.geom::owin(poly = list(x = rev(bnd[, 1]), y = rev(bnd[, 2])))
+    x = sp::coordinates(points)[, 1],
+    y = sp::coordinates(points)[, 2],
+    window = spatstat.geom::owin(
+      poly = list(x = rev(bnd[, 1]), y = rev(bnd[, 2]))
+    )
   )
 }
