@@ -62,13 +62,12 @@ test_that("sf gorillas lgcp vignette", {
   cmp <- geometry ~ mySmooth(geometry, model = matern) +
     Intercept(1)
 
-  expect_error(
+  expect_no_error(
     fit <- lgcp(
       cmp,
       data = gorillas_sf$nests,
       samplers = gorillas_sf$boundary,
       domain = list(geometry = mesh_sf)
-    ),
-    NA
+    )
   )
 })
