@@ -1,11 +1,13 @@
 test_that("Component construction: linear model", {
+  local_bru_safe_inla()
+
   df <- data.frame(x = 1:10, response = 1:10)
 
-  llik <- bru_like_list(list(bru_obs(formula = response ~ ., data = df)))
+  llik <- bru_obs_list(list(bru_obs(formula = response ~ ., data = df)))
 
   # Using label as input:
-  cmp0 <- bru_component_list(
-    list(bru_component("x", x)),
+  cmp0 <- bru_comp_list(
+    list(bru_comp("x", x)),
     lhoods = llik
   )[["x"]]
 
@@ -14,7 +16,7 @@ test_that("Component construction: linear model", {
   expect_equal(as.character(cmp0$main$input$input), "x")
 
   # Using label as input:
-  cmp0 <- bru_component_list(
+  cmp0 <- bru_comp_list(
     ~x,
     lhoods = llik
   )[["x"]]
@@ -23,7 +25,7 @@ test_that("Component construction: linear model", {
   expect_equal(cmp0$main$model, "linear")
   expect_equal(as.character(cmp0$main$input$input), "x")
 
-  cmp <- bru_component_list(
+  cmp <- bru_comp_list(
     ~ beta(main = x, model = "linear", values = 1),
     lhoods = llik
   )[["beta"]]
@@ -34,7 +36,7 @@ test_that("Component construction: linear model", {
 
   # Covariate mapping
   df <- data.frame(x = 1:10)
-  inp <- input_eval(cmp, data = df)
+  inp <- bru_input(cmp, data = df)
   expect_equal(
     inp,
     list(
@@ -47,7 +49,7 @@ test_that("Component construction: linear model", {
     )
   )
 
-  idx <- index_eval(cmp, inla_f = FALSE)
+  idx <- bru_index(cmp, inla_f = FALSE)
   expect_type(idx, "list")
   expect_equal(names(idx)[1], "beta")
   expect_equal(names(idx)[2], "beta.group")
@@ -55,7 +57,7 @@ test_that("Component construction: linear model", {
   expect_equal(idx$beta, 1)
 
   # A-matrix
-  comp_lin <- comp_lin_eval(cmp, input = inp, inla_f = FALSE)
+  comp_lin <- ibm_linear(cmp, input = inp, inla_f = FALSE)
   A <- ibm_jacobian(comp_lin)
   expect_s4_class(A, "dgCMatrix")
   expect_equal(nrow(A), 10)
@@ -69,28 +71,21 @@ test_that("Component construction: linear model", {
   v <- evaluate_effect_single_state(comp_lin, state = 2, A = A)
   expect_equal(v, 2 * df$x, ignore_attr = TRUE)
 
-  cmps <- bru_component_list(list(cmp))
-  inps <- input_eval(cmps, data = df)
-  v <- evaluate_effect_multi_state(
+  cmps <- bru_comp_list(list(cmp))
+  inps <- bru_input(cmps, data = df)
+  v <- evaluate_effect_single_state(
     cmps,
     input = inps,
-    state = list(list(beta = 2))
+    state = list(beta = 2)
   )
-  expect_equal(v[[1]][["beta"]], 2 * df$x, ignore_attr = TRUE)
-
-  v <- evaluate_effect_multi_state(
-    cmps,
-    input = inps,
-    state = list(list(beta = 2))
-  )
-  expect_equal(v[[1]][["beta"]], 2 * df$x, ignore_attr = TRUE)
+  expect_equal(v[["beta"]], 2 * df$x, ignore_attr = TRUE)
 })
 
 
 
 test_that("Component construction: duplicate detection", {
   expect_error(
-    bru_component_list(
+    bru_comp_list(
       ~ -1 +
         beta(main = x, model = "linear", values = 1) +
         beta(main = x, model = "linear", values = 2)
@@ -102,8 +97,8 @@ test_that("Component construction: duplicate detection", {
 
 
 test_that("Component construction: offset", {
-  cmp <- bru_component_list(~ -1 + something(a, model = "offset"))
-  inp <- input_eval(cmp, data = data.frame(a = 11:15))
+  cmp <- bru_comp_list(~ -1 + something(a, model = "offset"))
+  inp <- bru_input(cmp, data = data.frame(a = 11:15))
   val <- evaluate_effect_single_state(cmp,
     input = inp,
     state = NULL
@@ -136,14 +131,15 @@ test_that("Component construction: terra", {
 
   expect_equal(eval_spatial(r, data), 406)
 
-  llik <- bru_like_list(list(bru_obs(formula = response ~ ., data = data)))
+  llik <- bru_obs_list(list(bru_obs(formula = response ~ ., data = data)))
 
-  cmp <- bru_component_list(
+  local_bru_safe_inla()
+  cmp <- bru_comp_list(
     ~ -1 + something(eval_spatial(r, geometry), model = "linear"),
     lhoods = llik
   )
-  inp <- input_eval(cmp, data = data)
-  comp_lin <- comp_lin_eval(cmp,
+  inp <- bru_input(cmp, data = data)
+  comp_lin <- ibm_linear(cmp,
     input = inp,
     state = list(something = 2),
     inla_f = FALSE
@@ -157,11 +153,11 @@ test_that("Component construction: terra", {
     2 * 406
   )
 
-  cmp <- bru_component_list(~ -1 + something(r, model = "linear"),
+  cmp <- bru_comp_list(~ -1 + something(r, model = "linear"),
     lhoods = llik
   )
-  inp <- input_eval(cmp, data = data)
-  comp_lin <- comp_lin_eval(cmp,
+  inp <- bru_input(cmp, data = data)
+  comp_lin <- ibm_linear(cmp,
     input = inp,
     state = list(something = 2),
     inla_f = FALSE
@@ -175,12 +171,12 @@ test_that("Component construction: terra", {
     2 * 406
   )
 
-  cmp <- bru_component_list(
+  cmp <- bru_comp_list(
     ~ -1 + something(r, model = "linear", main_layer = 1),
     lhoods = llik
   )
-  inp <- input_eval(cmp, data = data)
-  comp_lin <- comp_lin_eval(cmp,
+  inp <- bru_input(cmp, data = data)
+  comp_lin <- ibm_linear(cmp,
     input = inp,
     state = list(something = 2),
     inla_f = FALSE
@@ -194,12 +190,12 @@ test_that("Component construction: terra", {
     2 * 406
   )
 
-  cmp <- bru_component_list(
+  cmp <- bru_comp_list(
     ~ -1 + something(r, model = "linear", main_layer = "elevation"),
     lhoods = llik
   )
-  inp <- input_eval(cmp, data = data)
-  comp_lin <- comp_lin_eval(cmp,
+  inp <- bru_input(cmp, data = data)
+  comp_lin <- ibm_linear(cmp,
     input = inp,
     state = list(something = 2),
     inla_f = FALSE
@@ -214,14 +210,14 @@ test_that("Component construction: terra", {
   )
 
   expect_error(
-    bru_component_list(~ something(r, model = "linear", main_layer = 2),
+    bru_comp_list(~ something(r, model = "linear", main_layer = 2),
       lhoods = llik
     ),
     NULL
   )
 
   expect_error(
-    bru_component_list(~ something(r, model = "linear", main_layer = "elev"),
+    bru_comp_list(~ something(r, model = "linear", main_layer = "elev"),
       lhoods = llik
     ),
     NULL
@@ -235,14 +231,15 @@ test_that("Component construction: default index/mesh/mapping construction", {
   skip_on_cran()
   local_bru_safe_inla()
 
-  lik <- bru_obs("gaussian",
+  lik <- bru_obs(
+    "gaussian",
     formula = y ~ .,
     data = data.frame(x = c(1, 1.5, 2, NA, 4), y = 11:15),
-    include = "effect"
+    used = bru_used(effect = "effect")
   )
 
-  cmp1 <- bru_component_list(~ effect(c(1, 1.5, 2, NA, 4), model = "iid") - 1)
-  cmp2 <- add_mappers(cmp1, lhoods = bru_like_list(list(lik)))
+  cmp1 <- bru_comp_list(~ effect(c(1, 1.5, 2, NA, 4), model = "iid") - 1)
+  cmp2 <- add_mappers(cmp1, lhoods = bru_obs_list(list(lik)))
   expect_equal(
     ibm_values(cmp2$effect$mapper, multi = 1)$main,
     sort(unique(lik$data$x), na.last = NA)
@@ -255,8 +252,8 @@ test_that("Component construction: default index/mesh/mapping construction", {
     c(11, 0, 14)
   )
 
-  cmp1 <- bru_component_list(~ effect(x, model = "rw2") - 1)
-  cmp2 <- add_mappers(cmp1, lhoods = bru_like_list(list(lik)))
+  cmp1 <- bru_comp_list(~ effect(x, model = "rw2") - 1)
+  cmp2 <- add_mappers(cmp1, lhoods = bru_obs_list(list(lik)))
   expect_equal(
     ibm_values(cmp2$effect$mapper, multi = 1)$main,
     sort(unique(lik$data$x), na.last = NA)
@@ -266,31 +263,31 @@ test_that("Component construction: default index/mesh/mapping construction", {
     sort(unique(lik$data$x), na.last = NA)
   )
   expect_error(
-    bru_component_list(
+    bru_comp_list(
       ~ effect(x, model = "rw2", mapper = mesh1) - 1
     ),
     regexp = "Unknown mapper"
   )
 
-  cmp1 <- bru_component_list(
+  cmp1 <- bru_comp_list(
     ~ effect(x,
       model = "rw2",
       mapper = bru_mapper(mesh1, indexed = FALSE)
     ) - 1
   )
-  cmp2 <- add_mappers(cmp1, lhoods = bru_like_list(list(lik)))
+  cmp2 <- add_mappers(cmp1, lhoods = bru_obs_list(list(lik)))
   expect_equal(
     ibm_values(cmp2$effect$mapper, multi = 1)$main,
     sort(unique(lik$data$x), na.last = NA)
   )
 
-  cmp1 <- bru_component_list(
+  cmp1 <- bru_comp_list(
     ~ effect(x,
       model = "rw2",
       mapper = bru_mapper(mesh1, indexed = TRUE)
     ) - 1
   )
-  cmp2 <- add_mappers(cmp1, lhoods = bru_like_list(list(lik)))
+  cmp2 <- add_mappers(cmp1, lhoods = bru_obs_list(list(lik)))
   expect_equal(
     ibm_values(cmp2$effect$mapper, multi = 1)$main,
     seq_along(sort(unique(lik$data$x), na.last = NA))
@@ -301,17 +298,18 @@ test_that("Component construction: default index/mesh/mapping construction", {
 
 test_that("Component construction: main iid factor construction", {
   skip_on_cran()
+  local_bru_safe_inla()
 
   lik <- bru_obs("gaussian",
     formula = y ~ .,
     data = data.frame(x = as.factor(c(1, 1.5, 2, 3, 4)), y = 11:15),
-    include = "effect"
+    used = bru_used(effect = "effect")
   )
 
-  cmp1 <- bru_component_list(~ effect(as.factor(c(1, 1.5, 2, 3, 4)),
+  cmp1 <- bru_comp_list(~ effect(as.factor(c(1, 1.5, 2, 3, 4)),
     model = "iid"
   ) - 1)
-  cmp2 <- add_mappers(cmp1, lhoods = bru_like_list(list(lik)))
+  cmp2 <- add_mappers(cmp1, lhoods = bru_obs_list(list(lik)))
   expect_equal(
     ibm_values(cmp2$effect$mapper, multi = 1)$main,
     as.character(lik$data$x)
@@ -328,14 +326,15 @@ test_that("Component construction: main iid factor construction", {
 
 test_that("Component construction: group iid factor construction", {
   skip_on_cran()
+  local_bru_safe_inla()
 
   lik <- bru_obs("gaussian",
     formula = y ~ .,
     data = data.frame(x = as.factor(c(1, 1.5, 2, 3, 4)), y = 11:15),
-    include = "effect"
+    used = bru_used(effect = "effect")
   )
 
-  cmp1 <- bru_component_list(
+  cmp1 <- bru_comp_list(
     ~ -1 +
       effect(rep(1, 5),
         group = x,
@@ -343,7 +342,7 @@ test_that("Component construction: group iid factor construction", {
         control.group = list(model = "iid")
       )
   )
-  cmp2 <- add_mappers(cmp1, lhoods = bru_like_list(list(lik)))
+  cmp2 <- add_mappers(cmp1, lhoods = bru_obs_list(list(lik)))
   expect_equal(
     ibm_values(cmp2$effect$mapper, multi = 1)$group,
     as.numeric(lik$data$x)
@@ -363,21 +362,22 @@ test_that("Component construction: group iid factor construction", {
 
 test_that("Component construction: replicate iid factor construction", {
   skip_on_cran()
+  local_bru_safe_inla()
 
   lik <- bru_obs("gaussian",
     formula = y ~ .,
     data = data.frame(x = as.factor(c(1, 1.5, 2, 3, 4)), y = 11:15),
-    include = "effect"
+    used = bru_used(effect = "effect")
   )
 
-  cmp1 <- bru_component_list(
+  cmp1 <- bru_comp_list(
     ~ -1 +
       effect(rep(1, 5),
         replicate = x,
         model = "iid"
       )
   )
-  cmp2 <- add_mappers(cmp1, lhoods = bru_like_list(list(lik)))
+  cmp2 <- add_mappers(cmp1, lhoods = bru_obs_list(list(lik)))
   expect_equal(
     ibm_values(cmp2$effect$mapper, multi = 1)$replicate,
     as.numeric(lik$data$x)
@@ -398,31 +398,19 @@ test_that("Component construction: replicate iid factor construction", {
 
 
 test_that("Component construction: unsafe intercepts", {
-  cmp <- bru_component_list(~ something_unknown - 1)
+  local_bru_safe_inla()
+
+  cmp <- bru_comp_list(~ something_unknown - 1)
   lik <- bru_obs(formula = response ~ ., data = data.frame(response = 1:5))
   lik <- bru_used_update(lik, labels = names(cmp))
-  expect_warning(
+  expect_error(
     object = {
-      model <- bru_model(cmp, bru_like_list(list(lik)))
+      model <- bru_model(cmp, bru_obs_list(list(lik)))
     },
-    "All covariate evaluations for 'something_unknown' are NULL"
-  )
-})
-
-test_that("Component construction: deprecated arguments", {
-  expect_warning(
-    bru_component_list(~ something(map = a)),
-    "Use of 'map' is deprecated"
-  )
-  skip_on_cran()
-  local_bru_safe_inla()
-  expect_warning(
-    bru(~ something(map = a),
-      formula = response ~ .,
-      data = data.frame(a = 1:5, response = 11:15),
-      options = list(bru_run = FALSE)
-    ),
-    "Use of 'map' is deprecated"
+    paste0(
+      "The input evaluation 'something_unknown' for 'something_unknown' ",
+      "failed. Perhaps the data object doesn't contain the needed variables?"
+    )
   )
 })
 
@@ -446,24 +434,24 @@ test_that("Component inputs: non-numeric input detection", {
   )
 
   # No model specified (argument unnamed), geometry invalid for
-  # bru_mapper_linear:
-  cmp <- bru_component_list(~ Intercept(1) + field(geometry, matern))
+  # bm_linear:
+  cmp <- bru_comp_list(~ Intercept(1) + field(geometry, matern))
   lk <- bru_obs(formula = obs ~ ., data = df, family = "gaussian")
   lk <- bru_used_update(lk, labels = names(cmp))
   model <- bru_model(cmp, c(lk))
 
   expect_error(
-    ibm_eval(bru_mapper_linear(), input = df$geometry, state = 1),
-    "The input to a bru_mapper_linear evaluation must be numeric or logical."
+    ibm_eval(bm_linear(), input = df$geometry, state = 1),
+    "The input to a bm_linear evaluation must be numeric or logical."
   )
 
-  cmp <- bru_component_list(
+  cmp <- bru_comp_list(
     ~ Intercept(1) + field(geometry, matern, model = matern)
   )
   lk <- bru_obs(formula = obs ~ ., data = df, family = "gaussian")
   lk <- bru_used_update(lk, labels = names(cmp))
   model <- bru_model(cmp, c(lk))
-  input <- input_eval(model$effects$field, data = df)
+  input <- bru_input(model$effects$field, data = df)
 
   expect_error(
     ibm_eval(
@@ -471,6 +459,6 @@ test_that("Component inputs: non-numeric input detection", {
       input = input,
       state = rep(1, fm_dof(mesh))
     ),
-    "The input to a bru_mapper_scale evaluation must be numeric or logical."
+    "The input to a bm_scale evaluation must be numeric or logical."
   )
 })
