@@ -3,7 +3,7 @@ test_that("bru: inla copy feature", {
   local_bru_safe_inla()
 
   # Seed influences data as well as predict()!
-  set.seed(123L)
+  withr::local_seed(123L)
 
   df1 <- data.frame(x = cos(1:100))
   df2 <- data.frame(x = sin(1:100))
@@ -19,21 +19,19 @@ test_that("bru: inla copy feature", {
         )
       ) +
       myLin2(x, copy = "myLin1", fixed = FALSE)
-  cmps <- bru_component_list(cmp)
+  cmps <- bru_comp_list(cmp)
 
   fit <- bru(
     cmp,
     bru_obs(
       y ~ Intercept + exp(myLin1),
       family = "gaussian",
-      data = df1,
-      exclude = "myLin2"
+      data = df1
     ),
     bru_obs(
       y ~ Intercept + (myLin2),
       family = "gaussian",
-      data = df2,
-      exclude = "myLin1"
+      data = df2
     ),
     options = list(control.inla = list(int.strategy = "eb"))
   )
@@ -68,7 +66,7 @@ test_that("bru: inla copy feature", {
 #   local_bru_safe_inla()
 #
 #   # Seed influences data as well as predict()!
-#   set.seed(123L)
+#   withr::local_seed(123L)
 #
 #   df1 <- data.frame(x = cos(1:100))
 #   df2 <- data.frame(x = sin(1:100))
@@ -88,7 +86,7 @@ test_that("bru: inla copy feature", {
 #     ) +
 #         myLin2(x, copy = "myLin1", fixed = FALSE, initial = 1)
 # #    myLin2(1)
-#   cmps <- bru_component_list(cmp)
+#   cmps <- bru_comp_list(cmp)
 #
 #   fit <- bru(
 #     cmp,
@@ -129,18 +127,22 @@ test_that("Component copy feature", {
   local_bru_safe_inla()
 
   # Seed influences data as well as predict()!
-  set.seed(123L)
+  withr::local_seed(123L)
 
   mydata <- data.frame(
-    x1 = rep(1:4, times = 2),
-    x2 = rep(c(1, 2), each = 4)
+    x0 = 1,
+    x1 = rep(1:20, times = 2) / 10,
+    x2 = rep(1:10, each = 4) / 10
   )
   mydata <- within(mydata, {
-    y <- rpois(8, exp(x1^0.5 + x2^0.5 * 2 - 1))
+    y <- rpois(
+      nrow(mydata),
+      exp(x1^0.5 + x2^0.5 * 2 + x0 * 3)
+    )
   })
 
-  inlaform <- y ~ -1 +
-    f(x1, model = "rw2", values = 1:4, scale.model = TRUE) +
+  inlaform <- y ~ 0 + x0 +
+    f(x1, model = "rw2", values = sort(unique(mydata$x1)), scale.model = TRUE) +
     f(x2, copy = "x1", fixed = FALSE)
   fit <- INLA::inla(
     formula = inlaform,
@@ -150,7 +152,7 @@ test_that("Component copy feature", {
     control.inla = list(int.strategy = "eb")
   )
 
-  cmp <- y ~ -1 +
+  cmp <- y ~ 0 + x0 +
     x1(x1, model = "rw2", scale.model = TRUE) +
     x2(x2, copy = "x1", fixed = FALSE)
   fit_bru <- bru(
@@ -161,9 +163,24 @@ test_that("Component copy feature", {
   )
 
   expect_equal(
-    fit_bru$summary.hyperpar,
-    fit$summary.hyperpar,
-    tolerance = midtol
+    fit_bru$summary.hyperpar$x1$mean,
+    fit$summary.hyperpar$x1$mean,
+    tolerance = lowtol
+  )
+  expect_equal(
+    fit_bru$summary.hyperpar$x2$mean,
+    fit$summary.hyperpar$x2$mean,
+    tolerance = lowtol
+  )
+  expect_equal(
+    fit_bru$summary.hyperpar$x1$sd,
+    fit$summary.hyperpar$x1$sd,
+    tolerance = hitol
+  )
+  expect_equal(
+    fit_bru$summary.hyperpar$x2$sd,
+    fit$summary.hyperpar$x2$sd,
+    tolerance = hitol
   )
 })
 
@@ -172,7 +189,7 @@ test_that("Component copy feature with group", {
   local_bru_safe_inla()
 
   # Seed influences data as well as predict()!
-  set.seed(123L)
+  withr::local_seed(123L)
 
   n <- c(16, 8)
   mydata <- data.frame(
