@@ -2,7 +2,7 @@ test_that("2D modelling on the globe", {
   skip_on_cran()
   local_bru_safe_inla()
 
-  set.seed(123L)
+  withr::local_seed(123L)
 
   options <- list(
     control.inla = list(
@@ -13,8 +13,8 @@ test_that("2D modelling on the globe", {
   mesh <- fm_rcdt_2d_inla(globe = 2)
 
   data <- data.frame(
-    Long = seq(-179, 179, length.out = 100),
-    Lat = seq(-89, 89, length.out = 100)
+    Long = rep(seq(-179, 179, length.out = 10), times = 10),
+    Lat = rep(seq(-89, 89, length.out = 10), each = 10)
   )
   data <- within(
     data,
@@ -46,14 +46,14 @@ test_that("2D modelling on the globe", {
 
   expect_equal(
     fit$summary.hyperpar["Range for mySmooth", "mean"],
-    2.5367148,
-    tolerance = hitol
+    2.7076690,
+    tolerance = midtol
   )
 
   expect_equal(
     fit$summary.hyperpar["Stdev for mySmooth", "mean"],
-    0.5494477,
-    tolerance = hitol
+    0.5524327,
+    tolerance = midtol
   )
 })
 
@@ -62,7 +62,7 @@ test_that("2D LGCP modelling on the globe", {
   skip_on_cran()
   local_bru_safe_inla()
 
-  set.seed(123L)
+  withr::local_seed(123L)
 
   options <- list(
     control.inla = list(
@@ -73,8 +73,11 @@ test_that("2D LGCP modelling on the globe", {
   mesh <- fm_rcdt_2d_inla(globe = 2, crs = fm_crs("sphere"))
 
   data <- data.frame(
-    Long = seq(-179, 179, length.out = 100),
-    Lat = seq(-89, 89, length.out = 100)
+    Long = rep(seq(0, 360 * 9 / 10, length.out = 10), times = 10),
+    Lat = 180 / pi * asin(rep(
+      seq(1 / 90, 89 / 90, length.out = 10)^0.5,
+      each = 10
+    ))
   )
   data <- sf::st_as_sf(data,
     coords = c("Long", "Lat"),
@@ -82,12 +85,9 @@ test_that("2D LGCP modelling on the globe", {
   )
   data <- fm_transform(data, crs = fm_crs("sphere"))
 
-  matern <- INLA::inla.spde2.pcmatern(
-    mesh,
-    prior.range = c(0.1, 0.01),
-    prior.sigma = c(0.1, 0.01)
-  )
-  cmp <- geometry ~ mySmooth(main = geometry, model = matern) - 1
+  cmp <- geometry ~
+    field(main = sf::st_coordinates(geometry), model = "fixed") +
+    Intercept(1)
 
   expect_equal(
     sum(fm_int(mesh)$weight),
@@ -105,14 +105,13 @@ test_that("2D LGCP modelling on the globe", {
   expect_s3_class(fit, "bru")
 
   expect_equal(
-    fit$summary.hyperpar["Range for mySmooth", "mean"],
-    1.5192092,
-    tolerance = hitol
+    fit$summary.random$field[, "mean"],
+    c(0, 0, 2.840911),
+    tolerance = midtol
   )
-
   expect_equal(
-    fit$summary.hyperpar["Stdev for mySmooth", "mean"],
-    0.8297119,
-    tolerance = hitol
+    fit$summary.random$field[, "sd"],
+    c(0.2089972, 0.2089972, 0.2968185),
+    tolerance = midtol
   )
 })
