@@ -1,8 +1,8 @@
 latent_spde1D_testdata <- function() {
   local_bru_safe_inla()
   data(Poisson2_1D, package = "inlabru", envir = environment())
-  x <- seq(0, 55, length = 50)
-  mesh1D <- INLA::inla.mesh.1d(x, boundary = "free")
+  x <- seq(0, 55, length.out = 50)
+  mesh1D <- fm_mesh_1d(x, boundary = "free")
 
   matern <- INLA::inla.spde2.pcmatern(mesh1D,
     prior.range = c(1, 0.01),
